Learn R Programming

Rtextrankr (version 1.0.0)

get_sentences: Make character string list which ends with a period, from the whole text. Example will be shown in github.

Description

Make character string list which ends with a period, from the whole text. Example will be shown in github.

Usage

get_sentences(text)

Arguments

text
The long character string including delimiter([.|!|?|blank line]).

Value

The list of character string which ends with a period.