Learn R Programming

Rtextrankr (version 1.0.0)

summarize: Return list of character string of the most important sentences by Textrank algorithm. Example will be shown in github.

Description

Return list of character string of the most important sentences by Textrank algorithm. Example will be shown in github.

Usage

summarize(text, count)

Arguments

text
The long character string including delimiter([.|!|?|blank line]).
count
The number of summarized sentences.

Value

The list of character string of the most important sentences by Textrank algorithm.

References

Mihalcea, R., & Tarau, P. (2004, July). TextRank: Bringing order into texts. Association for Computational Linguistics.